@@ -4,11 +4,9 @@ use strict;
 use warnings;
 use Config;
 use Module::Build;
-use File::Basename;
-use File::Path;
 our @ISA = qw(Module::Build);
 
-our $VERSION = "0.11_01";
+our $VERSION = "0.01";
 
 __PACKAGE__->add_property( 'ppport_h_path'   => undef );
 __PACKAGE__->add_property( 'xshelper_h_path' => undef );
@@ -20,10 +18,6 @@ sub new {
 
     my $self = $class->SUPER::new(%args);
 
-    if ( !defined $args{cc_warnings} ) {
-        $args{cc_warnings} = 1;
-    }
-
     unless ( $self->have_c_compiler() ) {
         warn "This distribution requires a C compiler, but it's not available, stopped.\n";
         exit -1;
@@ -76,7 +70,7 @@ sub new {
     if ( $args{cc_warnings} ) {
         $self->_add_extra_compiler_flags( $self->_cc_warnings( \%args ) );
     }
-
+    
     # xshelper.h
     if ( my $xshelper = $args{generate_xshelper_h} ) {
         if ( $xshelper eq '1' ) {    # { xshelper => 1 }
@@ -110,10 +104,9 @@ sub ACTION_code {
     # write xshelper.h
     if ( my $xshelper = $self->xshelper_h_path ) {
         File::Path::mkpath( File::Basename::dirname($xshelper) );
-        
-        if ( open(my $fh, '>', $xshelper) ) {
-            print $fh _xshelper_h();
-            close $fh;
+        if ( my $fh = IO::File->new("> $xshelper") ) {
+            $fh->print( _xshelper_h() );
+            $fh->close;
         }
     }
 
@@ -130,10 +123,9 @@ sub ACTION_manifest_skip {
     my $self = shift;
     $self->SUPER::ACTION_manifest_skip(@_);
     if ( -e 'MANIFEST.SKIP' ) {
-        open(my $fh, '<', 'MANIFEST.SKIP') or die $!;
+        my $fh = IO::File->new("< MANIFEST.SKIP");
         my $content = do { local $/; <$fh> };
-        close $fh;
-        my $ppport  = $self->ppport_h_path;
+        my $ppport = $self->ppport_h_path;
         if ( $ppport && $content !~ /\Q${ppport}\E/ ) {
 
             my $safe = quotemeta($ppport);
@@ -151,6 +143,7 @@ sub ACTION_manifest_skip {
 sub auto_require {
     my ($self) = @_;
     my $p = $self->{properties};
+
     if (    $self->dist_name ne 'Module-Build-XSUtil'
         and $self->auto_configure_requires )
     {
@@ -196,14 +189,14 @@ sub _cc_warnings {
         my $gccversion = $self->_gcc_version();
         if ( $gccversion >= 4.0 ) {
             push @flags, qw(-Wextra);
-            if ( !( $args->{needs_compiler_c99} or $args->{needs_compiler_cpp} ) ) {
+            if ( !( $args->{c99} or $args->{'c++'} ) ) {
 
                 # Note: MSVC++ doesn't support C99,
                 # so -Wdeclaration-after-statement helps
                 # ensure C89 specs.
                 push @flags, qw(-Wdeclaration-after-statement);
             }
-            if ( $gccversion >= 4.1 && !$args->{needs_compiler_cpp} ) {
+            if ( $gccversion >= 4.1 && !$args->{'c++'} ) {
                 push @flags, qw(-Wc++-compat);
             }
         }
@@ -364,7 +357,7 @@ Use in your Build.PL
         dist_author          => 'Your Name <yourname@example.com>',
         dist_version_from    => 'lib/Your/XS/Module',
         generate_ppport_h    => 'lib/Your/XS/ppport.h',
-        generate_xshelper_h  => 'lib/Your/XS/xshelper.h',
+        generate_xs_helper_h => 'lib/Your/XS/xshelper.h',
         needs_compiler_c99   => 1,
     );
     
@@ -382,7 +375,7 @@ Use in custom builder module.
         my $self = $class->SUPER::new(
             %args,
             generate_ppport_h    => 'lib/Your/XS/ppport.h',
-            generate_xshelper_h  => 'lib/Your/XS/xshelper.h',
+            generate_xs_helper_h => 'lib/Your/XS/xshelper.h',
             needs_compiler_c99   => 1,
         );
         return $self;
@@ -430,7 +423,7 @@ If invoke Build.PL with '-g' option, It will build with debug options.
 
 =back
 
-=head1 SEE ALSO
+=head1 SEE ALOS
 
 L<Module::Install::XSUtil>
 
